# Emperor's resources

The organization of this directory should be as follows:

- `js/` should contain only JavaScript source code from Emperor.
- `css/` should contain only CSS source code from Emperor.
- `img/` should contain images that are only by Emperor.
- `vendor/` should contain any third party code used in the project. If it is a JavaScript file the files should live in `vendor/js/` and if it is a CSS file the files should live in `vendor/css/`.
